@@ -468,7 +468,7 @@ class BaseFormMixin(ActionResponseMixin):
         context = super(BaseFormMixin, self).get_context_data(*args, **kwargs)
         
         if self.get_format() == 'json':
-            context['form'] = render_to_string(self.template_form, context)
+            context['form_html'] = render_to_string(self.template_form, context)
         
         return context
 
